@@ -18,12 +18,15 @@ class TextComparator(BaseComparator):
     chars_to_ignore: ClassVar[str] = '\r'
     def compare(self, value: str) -> ComparisonBuffer:
         expected = self.expected
+        actual = value
         for char in self.chars_to_ignore:
             # expected = expected.replace(char, '')
+            # actual = actual.replace(char, '')
             pass
-        actual = value.replace('\r', '')
         result = ComparisonBuffer()
-        for expected_line, actual_line in zip(expected.splitlines(), actual.splitlines()):
+        expected_lines = expected.splitlines()
+        actual_lines = actual.splitlines()
+        for expected_line, actual_line in zip(expected_lines, actual_lines):
             if '...' in expected_line:
                 comparator = compare_string_with_pattern
                 error_text = 'Value mismatch'
@@ -32,4 +35,8 @@ class TextComparator(BaseComparator):
                 error_text = 'Value non equal'
             exception = None if comparator(expected_line, actual_line) else ValueError(error_text)
             result.append(TextComparisonLine(expected_line, actual_line, exception))
+        for i in range(len(actual_lines), len(expected_lines)):
+            result.append(TextComparisonLine(expected_lines[i], '', ValueError(f"Missing line")))
+        for i in range(len(expected_lines), len(actual_lines)):
+            result.append(TextComparisonLine('', actual_lines[i], ValueError(f"Extra line")))
         return result
